ams.cli
=======

.. automodule:: ams.cli

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
      :toctree:
   
      create_parser
      main
      preamble
   
   

   
   
   

   
   
   



